platform

package
v0.2.21 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 10, 2021 License: Apache-2.0 Imports: 0 Imported by: 0

Documentation

Index

Constants

const Amd64 = "amd64"

Amd64 architecture

const Arm64 = "arm64"

Arm64 architecture

const Darwin = "darwin"

Darwin OS

const Linux = "linux"

Linux OS

Variables

var Core = []Platform{
	{Linux, Amd64},
	{Darwin, Amd64},
	{Darwin, Arm64},
}

Core platforms are core platforms officially supported by Hermit. For a package to be considered fully compliant, these platforms need to be supported

Functions

This section is empty.

Types

type Platform

type Platform struct {
	// OS is the operating system of the platform
	OS string
	// Arch is the CPU architecture of the platform
	Arch string
}

Platform describes a system where a package can be installed

func (Platform) String

func (p Platform) String() string

Jump to